require('dotenv').config();
import axios from "axios";
import { GoogleCalendarEvent } from "./types";
import { parse } from 'node-html-parser';
import moment from 'moment'; // require

// This calss will be the game source.
// search for upcomming games

export default class GameSource {

  async getGamesFromHaifa(): Promise<GoogleCalendarEvent[]> {
    const sourceUrl = `https://mhaifafc.com/games?lang=en`;
    const result = await axios.get(sourceUrl);
    const parsedResult = parse(result.data.toString())
    const gameBoxs = parsedResult.querySelectorAll(".game-box");

    const games: GoogleCalendarEvent[] = [];

    for (let gameBox of gameBoxs) {
      
      const teamsPlaying = gameBox.querySelectorAll(".team-name").map((team: any) => team.text);
      const regex = /[\r\n\s]+/g;
      const gameHeader = gameBox.querySelector(".game-header").text.replace(regex, " ").trim();
      const headerSplit = gameHeader.split(",");
      // In data, if there is no time, it means it's the last game for the calender
      const lastGameForCalender = headerSplit.length < 4;
      if (lastGameForCalender) break;
      
      const gameDate = headerSplit[2].trim();
      const gameTime = headerSplit[3].trim();

      const startOriginal = moment(gameDate + gameTime, "DD/MM/YYYYHH:mm").format("DD/MM/YYYY HH:mm");
      const endOriginal = moment(gameDate + gameTime, "DD/MM/YYYYHH:mm").add(2, "hours").format("DD/MM/YYYY HH:mm");

      const start = [moment(startOriginal, 'DD/MM/YYYYHH:mm').year(), moment(startOriginal, 'DD/MM/YYYYHH:mm').month() + 1, moment(startOriginal, 'DD/MM/YYYYHH:mm').date(), moment(startOriginal, 'DD/MM/YYYYHH:mm').hour(), moment(startOriginal, 'DD/MM/YYYYHH:mm').minute()];
      const end = [moment(endOriginal, 'DD/MM/YYYYHH:mm').year(), moment(endOriginal, 'DD/MM/YYYYHH:mm').month() + 1, moment(endOriginal, 'DD/MM/YYYYHH:mm').date(), moment(endOriginal, 'DD/MM/YYYYHH:mm').hour(), moment(endOriginal, 'DD/MM/YYYYHH:mm').minute()]
     
      games.push({ 
        summary: 'Maccabi Haifa F.C.',
        location: "Sammy Ofer Stadium",
        description: `${teamsPlaying[0]} vs. ${teamsPlaying[1]}`,
        start: {
          dateTime: start,
          timeZone: 'Asia/Jerusalem'
        },
        end: {
          dateTime: end,
          timeZone: 'Asia/Jerusalem'
        }
      })
    }
    return games;
  }

  getOpponentIndexByStadium(stadium: string) {
    if (stadium === "Sammy Ofer Stadium") {
      return 1;
    } else {
      return 0;
    }
  }
}