import { GoogleCalendarEvent } from "./types";
import * as ics from 'ics';

const uuid = require('uuid').v4();


export default class Ics {

  generateIcsOutputFromGames = (games: GoogleCalendarEvent[]) => {
    let output = [];
    games.forEach((game) => {
      output.push(this.generateIcsOutputFromGame(game));
    });

    const { error, value } = ics.createEvents(output);
    if (error) {
      console.log(error);
      return '';
    }
    return value;
  }

  generateIcsOutputFromGame = (game: GoogleCalendarEvent) => {
    const { summary, location, description, start, end } = game;
    const icsEvent: ics.EventAttributes = {
      title: summary,
      description,
      location,
      start: [start.dateTime[0], start.dateTime[1], start.dateTime[2], start.dateTime[3], start.dateTime[4]],
      end: [end.dateTime[0], end.dateTime[1], end.dateTime[2], end.dateTime[3], end.dateTime[4]],
      url: 'https://mhaifafc.com/',
      status: 'CONFIRMED',
      busyStatus: 'BUSY',
      productId: 'https://mhaifafc.com/',
      recurrenceRule: '',
      attendees: [],
      alarms: [],
      categories: [],
      organizer: { name: 'Maccabi Haifa F.C.', email: '' }
    };
    return icsEvent;
  }
} 